/*! normalize-scss | MIT/GPLv2 License | bit.ly/normalize-scss */
/* Document
       ========================================================================== */
/**
     * 1. Change the default font family in all browsers (opinionated).
     * 2. Correct the line height in all browsers.
     * 3. Prevent adjustments of font size after orientation changes in
     *    IE on Windows Phone and in iOS.
     */
html {
  font-family: sans-serif;
  /* 1 */
  line-height: 1.15;
  /* 2 */
  -ms-text-size-adjust: 100%;
  /* 3 */
  -webkit-text-size-adjust: 100%;
  /* 3 */ }

/* Sections
       ========================================================================== */
/**
     * Remove the margin in all browsers (opinionated).
     */
body {
  margin: 0; }

/**
     * Add the correct display in IE 9-.
     */
article,
aside,
footer,
header,
nav,
section {
  display: block; }

/**
     * Correct the font size and margin on `h1` elements within `section` and
     * `article` contexts in Chrome, Firefox, and Safari.
     */
h1 {
  font-size: 2em;
  margin: 0.67em 0; }

/* Grouping content
       ========================================================================== */
/**
     * Add the correct display in IE 9-.
     */
figcaption,
figure {
  display: block; }

/**
     * Add the correct margin in IE 8.
     */
figure {
  margin: 1em 40px; }

/**
     * 1. Add the correct box sizing in Firefox.
     * 2. Show the overflow in Edge and IE.
     */
hr {
  box-sizing: content-box;
  /* 1 */
  height: 0;
  /* 1 */
  overflow: visible;
  /* 2 */ }

/**
     * Add the correct display in IE.
     */
main {
  display: block; }

/**
     * 1. Correct the inheritance and scaling of font size in all browsers.
     * 2. Correct the odd `em` font sizing in all browsers.
     */
pre {
  font-family: monospace, monospace;
  /* 1 */
  font-size: 1em;
  /* 2 */ }

/* Links
       ========================================================================== */
/**
     * 1. Remove the gray background on active links in IE 10.
     * 2. Remove gaps in links underline in iOS 8+ and Safari 8+.
     */
a {
  background-color: transparent;
  /* 1 */
  -webkit-text-decoration-skip: objects;
  /* 2 */ }

/**
     * Remove the outline on focused links when they are also active or hovered
     * in all browsers (opinionated).
     */
a:active,
a:hover {
  outline-width: 0; }

/* Text-level semantics
       ========================================================================== */
/**
     * 1. Remove the bottom border in Firefox 39-.
     * 2. Add the correct text decoration in Chrome, Edge, IE, Opera, and Safari.
     */
abbr[title] {
  border-bottom: none;
  /* 1 */
  text-decoration: underline;
  /* 2 */
  text-decoration: underline dotted;
  /* 2 */ }

/**
     * Prevent the duplicate application of `bolder` by the next rule in Safari 6.
     */
b,
strong {
  font-weight: inherit; }

/**
     * Add the correct font weight in Chrome, Edge, and Safari.
     */
b,
strong {
  font-weight: bolder; }

/**
     * 1. Correct the inheritance and scaling of font size in all browsers.
     * 2. Correct the odd `em` font sizing in all browsers.
     */
code,
kbd,
samp {
  font-family: monospace, monospace;
  /* 1 */
  font-size: 1em;
  /* 2 */ }

/**
     * Add the correct font style in Android 4.3-.
     */
dfn {
  font-style: italic; }

/**
     * Add the correct background and color in IE 9-.
     */
mark {
  background-color: #ff0;
  color: #000; }

/**
     * Add the correct font size in all browsers.
     */
small {
  font-size: 80%; }

/**
     * Prevent `sub` and `sup` elements from affecting the line height in
     * all browsers.
     */
sub,
sup {
  font-size: 75%;
  line-height: 0;
  position: relative;
  vertical-align: baseline; }

sub {
  bottom: -0.25em; }

sup {
  top: -0.5em; }

/* Embedded content
       ========================================================================== */
/**
     * Add the correct display in IE 9-.
     */
audio,
video {
  display: inline-block; }

/**
     * Add the correct display in iOS 4-7.
     */
audio:not([controls]) {
  display: none;
  height: 0; }

/**
     * Remove the border on images inside links in IE 10-.
     */
img {
  border-style: none; }

/**
     * Hide the overflow in IE.
     */
svg:not(:root) {
  overflow: hidden; }

/* Forms
       ========================================================================== */
/**
     * 1. Change the font styles in all browsers (opinionated).
     * 2. Remove the margin in Firefox and Safari.
     */
button,
input,
optgroup,
select,
textarea {
  font-family: sans-serif;
  /* 1 */
  font-size: 100%;
  /* 1 */
  line-height: 1.15;
  /* 1 */
  margin: 0;
  /* 2 */ }

/**
     * Show the overflow in IE.
     */
button {
  overflow: visible; }

/**
     * Remove the inheritance of text transform in Edge, Firefox, and IE.
     * 1. Remove the inheritance of text transform in Firefox.
     */
button,
select {
  /* 1 */
  text-transform: none; }

/**
     * 1. Prevent a WebKit bug where (2) destroys native `audio` and `video`
     *    controls in Android 4.
     * 2. Correct the inability to style clickable types in iOS and Safari.
     */
button,
html [type="button"],
[type="reset"],
[type="submit"] {
  -webkit-appearance: button;
  /* 2 */ }

button,
[type="button"],
[type="reset"],
[type="submit"] {
  /**
       * Remove the inner border and padding in Firefox.
       */
  /**
       * Restore the focus styles unset by the previous rule.
       */ }
  button::-moz-focus-inner,
  [type="button"]::-moz-focus-inner,
  [type="reset"]::-moz-focus-inner,
  [type="submit"]::-moz-focus-inner {
    border-style: none;
    padding: 0; }
  button:-moz-focusring,
  [type="button"]:-moz-focusring,
  [type="reset"]:-moz-focusring,
  [type="submit"]:-moz-focusring {
    outline: 1px dotted ButtonText; }

/**
     * Show the overflow in Edge.
     */
input {
  overflow: visible; }

/**
     * 1. Add the correct box sizing in IE 10-.
     * 2. Remove the padding in IE 10-.
     */
[type="checkbox"],
[type="radio"] {
  box-sizing: border-box;
  /* 1 */
  padding: 0;
  /* 2 */ }

/**
     * Correct the cursor style of increment and decrement buttons in Chrome.
     */
[type="number"]::-webkit-inner-spin-button,
[type="number"]::-webkit-outer-spin-button {
  height: auto; }

/**
     * 1. Correct the odd appearance in Chrome and Safari.
     * 2. Correct the outline style in Safari.
     */
[type="search"] {
  -webkit-appearance: textfield;
  /* 1 */
  outline-offset: -2px;
  /* 2 */
  /**
       * Remove the inner padding and cancel buttons in Chrome and Safari on macOS.
       */ }
  [type="search"]::-webkit-search-cancel-button, [type="search"]::-webkit-search-decoration {
    -webkit-appearance: none; }

/**
     * 1. Correct the inability to style clickable types in iOS and Safari.
     * 2. Change font properties to `inherit` in Safari.
     */
::-webkit-file-upload-button {
  -webkit-appearance: button;
  /* 1 */
  font: inherit;
  /* 2 */ }

/**
     * Change the border, margin, and padding in all browsers (opinionated).
     */
fieldset {
  border: 1px solid #c0c0c0;
  margin: 0 2px;
  padding: 0.35em 0.625em 0.75em; }

/**
     * 1. Correct the text wrapping in Edge and IE.
     * 2. Correct the color inheritance from `fieldset` elements in IE.
     * 3. Remove the padding so developers are not caught out when they zero out
     *    `fieldset` elements in all browsers.
     */
legend {
  box-sizing: border-box;
  /* 1 */
  display: table;
  /* 1 */
  max-width: 100%;
  /* 1 */
  padding: 0;
  /* 3 */
  color: inherit;
  /* 2 */
  white-space: normal;
  /* 1 */ }

/**
     * 1. Add the correct display in IE 9-.
     * 2. Add the correct vertical alignment in Chrome, Firefox, and Opera.
     */
progress {
  display: inline-block;
  /* 1 */
  vertical-align: baseline;
  /* 2 */ }

/**
     * Remove the default vertical scrollbar in IE.
     */
textarea {
  overflow: auto; }

/* Interactive
       ========================================================================== */
/*
     * Add the correct display in Edge, IE, and Firefox.
     */
details {
  display: block; }

/*
     * Add the correct display in all browsers.
     */
summary {
  display: list-item; }

/*
     * Add the correct display in IE 9-.
     */
menu {
  display: block; }

/* Scripting
       ========================================================================== */
/**
     * Add the correct display in IE 9-.
     */
canvas {
  display: inline-block; }

/**
     * Add the correct display in IE.
     */
template {
  display: none; }

/* Hidden
       ========================================================================== */
/**
     * Add the correct display in IE 10-.
     */
[hidden] {
  display: none; }

/* prevent element from being selected http://stackoverflow.com/questions/826782 */
.noselect, .voyager h1, .voyager h2, .voyager h3 {
  -webkit-user-select: none;
     -moz-user-select: none;
      -ms-user-select: none;
          user-select: none;
  cursor: default; }

.voyager {
  font-size: 12px;
  margin: 0;
  padding: 0;
  background-color: #E2E9F3;
  height: inherit;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
      -ms-flex-direction: column;
          flex-direction: column; }
  .voyager .SplitPane {
    position: relative !important; }
  .voyager .right {
    float: right; }
  .voyager .hidden {
    visibility: hidden; }
  .voyager h1 {
    font-size: 24px;
    line-height: 36px;
    font-weight: 700;
    margin: 0; }
  .voyager h2 {
    font-size: 16px;
    line-height: 20px;
    font-weight: 700;
    margin: 0 0 10px;
    color: #38425d; }
  .voyager h3 {
    font-size: 14px;
    font-weight: 700;
    margin: 0 0 6px;
    color: #38425d; }
  .voyager h4 {
    font-size: 12px;
    margin: 0 0 6px; }
  .voyager .modal-header {
    background-color: #f1f4f9;
    -ms-flex-negative: 0;
        flex-shrink: 0;
    margin: 3px 3px 0 0;
    padding: 8px;
    margin-top: 0;
    margin-right: 0; }
  .voyager .pane {
    padding: 8px; }
  .voyager .persist-scroll {
    /*
      Prevent scroll bars from being hidden for OS X.
      http://stackoverflow.com/questions/7855590/how-can-i-prevent-scroll-bars-from-being-hidden-for-os-x-trackpad-users-in-webkit
    */ }
    .voyager .persist-scroll::-webkit-scrollbar {
      -webkit-appearance: none; }
    .voyager .persist-scroll::-webkit-scrollbar:vertical {
      width: 11px; }
    .voyager .persist-scroll::-webkit-scrollbar:horizontal {
      height: 11px; }
    .voyager .persist-scroll::-webkit-scrollbar-thumb {
      border-radius: 8px;
      border: 2px solid white;
      /* should match background, can't be transparent */
      background-color: rgba(0, 0, 0, 0.5); }
    .voyager .persist-scroll::-webkit-scrollbar-track {
      background-color: transparent;
      border-radius: 8px; }
  .voyager div, .voyager span {
    -webkit-user-select: none;
       -moz-user-select: none;
        -ms-user-select: none;
            user-select: none; }
  .voyager .fa.fa-times, .voyager .fa.fa-search, .voyager .fa.fa-pencil, .voyager .fa.fa-caret-down, .voyager .fa.fa-times, .voyager .fa.fa-plus, .voyager .fa.fa-filter {
    padding: 2px 3px 1px;
    border-radius: 3px; }
    .voyager .fa.fa-times:hover, .voyager .fa.fa-search:hover, .voyager .fa.fa-pencil:hover, .voyager .fa.fa-caret-down:hover, .voyager .fa.fa-times:hover, .voyager .fa.fa-plus:hover, .voyager .fa.fa-filter:hover {
      color: #fff;
      background-color: #999; }
  .voyager .react-spinners--clip {
    margin: auto; }
  .voyager .chart > canvas, .voyager .chart > svg {
    margin: auto;
    display: block; }
  .voyager .chart {
    margin: auto; }
  .voyager .Resizer {
    opacity: .2;
    z-index: 1;
    box-sizing: border-box;
    background-clip: padding-box; }
  .voyager .Resizer:hover {
    -webkit-transition: all 2s ease;
    transition: all 2s ease; }
  .voyager .Resizer.horizontal {
    height: 11px;
    margin: -5px 0;
    border-top: 5px solid rgba(255, 255, 255, 0);
    border-bottom: 5px solid rgba(255, 255, 255, 0);
    cursor: row-resize;
    width: 100%; }
  .voyager .Resizer.horizontal:hover {
    border-top: 5px solid transparent;
    border-bottom: 5px solid transparent; }
  .voyager .Resizer.vertical {
    width: 11px;
    margin: 0 -5px;
    border-left: 5px solid rgba(255, 255, 255, 0);
    border-right: 5px solid rgba(255, 255, 255, 0);
    cursor: col-resize; }
  .voyager .Resizer.vertical:hover {
    overflow-y: hidden;
    border-left: 5px solid transparent;
    border-right: 5px solid transparent; }
  .voyager .Resizer.disabled {
    cursor: not-allowed; }
  .voyager .Resizer.disabled:hover {
    border-color: transparent; }
  .voyager .vg-tooltip {
    visibility: hidden;
    padding: 6px;
    border-radius: 3px;
    position: fixed;
    z-index: 2000;
    font-family: sans-serif;
    font-size: 11px;
    /* The default look of the tooltip is the same as .light-theme
    but it can be overwritten by .dark-theme */
    background-color: rgba(255, 255, 255, 0.9);
    border: 1px solid #d9d9d9;
    color: black; }
  .voyager .key {
    overflow: hidden;
    text-overflow: ellipsis;
    color: #808080;
    max-width: 150px;
    text-align: right;
    padding-right: 1px; }
  .voyager .value {
    overflow: hidden;
    text-overflow: ellipsis;
    max-width: 200px;
    text-align: left; }
.data-selector__data-selector {
  z-index: 1; }

.data-selector__modal {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  margin: 50px auto;
  width: calc( 100% - 100px);
  padding: 6px;
  background-color: #E2E9F3;
  border: 1px solid #aaa;
  border-radius: 3px;
  box-sizing: border-box;
  display: flex;
  box-orient: vertical;
  box-direction: normal;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
      -ms-flex-direction: column;
          flex-direction: column;
  box-align: stretch;
  -webkit-box-align: stretch;
      -ms-flex-align: stretch;
          align-items: stretch;
  max-width: 800px; }

.data-selector__modal-close {
  float: right; }

.data-selector__tab-list {
  border-bottom: 1px solid #aaa;
  margin: 0 0 10px;
  padding: 0; }

.data-selector__tab-panel {
  display: none;
  padding: 10px; }

.data-selector__tab {
  display: inline-block;
  border: 1px solid #ddd;
  border-radius: 5px 5px 0 0;
  border-bottom: none;
  bottom: -1px;
  position: relative;
  list-style: none;
  padding: 6px 12px;
  cursor: pointer;
  margin-right: 5px; }

.data-selector__react-tabs {
  z-index: 10;
  background-color: white; }
  .react-tabs__tab--selected {
    background: #fff;
    border-color: #aaa;
    color: black; }
  .data-selector__react-tabs:focus {
    box-shadow: 0 0 5px #0188fe;
    border-color: #0188fe;
    outline: none; }
    .data-selector__react-tabs:focus:after {
      content: "";
      position: absolute;
      height: 5px;
      left: -4px;
      right: -4px;
      bottom: -5px;
      background: #fff; }
  .react-tabs__tab-panel--selected {
    display: block; }

.data-selector__dataset-list {
  padding: 0;
  list-style-type: none;
  margin-bottom: 20px; }

.data-selector__dataset-list-element {
  cursor: pointer;
  margin-bottom: 20px;
  margin-bottom: 5px;
  display: inline-block;
  vertical-align: top;
  box-sizing: border-box;
  padding: 5px 20px 5px 10px;
  width: 49%; }

.data-selector__dataset-list-element.data-selector__element-selected {
  background-color: #eef0f7;
  border: 1px solid #aeb8d4;
  border-radius: 3px; }

.data-selector__dataset-list-element:hover {
  color: #72757B; }

.data-selector__upload-panel {
  width: 50%;
  display: inline-block;
  vertical-align: top;
  margin-left: 20px; }
  .data-selector__upload-panel .form-group {
    margin-top: 1em; }
  .data-selector__upload-panel label {
    width: 50px;
    display: block;
    float: left;
    font-weight: bold;
    margin-right: 10px; }

.data-selector__paste-panel {
  width: 44%;
  display: inline-block;
  vertical-align: top;
  margin-left: 20px; }
  .data-selector__paste-panel .form-group {
    margin-top: 1em; }
  .data-selector__paste-panel label {
    width: 50px;
    display: block;
    float: left;
    font-weight: bold;
    margin-right: 10px; }
  .data-selector__paste-panel textarea {
    min-height: 200px;
    width: 90%; }

.data-selector__url-panel {
  width: 50%;
  display: inline-block;
  vertical-align: top;
  margin-left: 20px; }
  .data-selector__url-panel .form-group {
    margin-top: 1em;
    clear: both; }
  .data-selector__url-panel label {
    width: 55px;
    display: block;
    float: left;
    font-weight: bold;
    margin-right: 10px; }
  .data-selector__url-panel button {
    margin-top: 0.5em; }

.data-selector__dropzone-target {
  width: 100%;
  padding: 20px;
  box-sizing: border-box;
  border-radius: 4px;
  border: 1px dashed #aaa;
  color: #888;
  font-weight: bold;
  text-align: center;
  text-transform: uppercase;
  padding: 50px 20px; }
.data-pane__data-pane {
  background-color: #38425D;
  height: 100%; }
  .data-pane__data-pane .data-pane__current-dataset {
    color: white; }
  .data-pane__data-pane .data-pane__data-pane-section {
    margin-top: 16px; }
  .data-pane__data-pane h2.data-pane__data-pane-title, .data-pane__data-pane .data-pane__data-pane-section h3 {
    color: white; }
.field__field, .field__field-pill, .field__wildcard-field-pill {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  vertical-align: middle;
  border-radius: 3px;
  line-height: 18px;
  box-sizing: border-box;
  height: 20px;
  padding: 1px 3px;
  font-size: 11px;
  border: 1px solid transparent;
  -webkit-user-select: none;
     -moz-user-select: none;
      -ms-user-select: none;
          user-select: none;
  overflow: hidden; }

.field__func {
  text-transform: uppercase;
  font-weight: 700;
  font-size: 11px;
  margin-right: 2px;
  -ms-flex-negative: 0;
      flex-shrink: 0; }

.field__field-pill {
  background-color: rgba(237, 237, 237, 0.8);
  font-weight: 500;
  width: 100%; }

.field__wildcard-field-pill {
  background-color: rgba(216, 250, 251, 0.8);
  font-weight: 500;
  width: 100%; }

.field__caret-type {
  -ms-flex-negative: 0;
      flex-shrink: 0; }

.field__type {
  font-size: 0.8rem;
  margin-right: 3px;
  margin-right: 6px;
  -ms-flex-negative: 0;
      flex-shrink: 0; }

.field__text, .field__fn-text {
  -webkit-box-flex: 1;
      -ms-flex-positive: 1;
          flex-grow: 1;
  text-overflow: ellipsis;
  overflow: hidden;
  white-space: nowrap; }

.field__fn-text {
  -webkit-box-flex: 1;
      -ms-flex-positive: 1;
          flex-grow: 1; }
  .field__fn-text::before {
    content: "("; }
  .field__fn-text::after {
    content: ")"; }

.field__filter-button-unadded {
  color: #7f7f7f; }
.field-list__field-list {
  max-height: calc(50vh);
  overflow-y: auto; }

.field-list__field-list-item {
  margin-bottom: 4px; }
.type-changer__type-changer {
  background-color: #eee;
  padding: 10px;
  border: 1px solid #eee;
  border-radius: 3px;
  margin-left: 10px; }
  .type-changer__type-changer h4 {
    font-size: 12px;
    margin: 0 0 6px; }
  .type-changer__type-changer label {
    font-size: 11px; }

.type-changer__type {
  margin: 3px; }

#type-changer__type-changer-pop-up {
  pointer-events: none; }
.function-picker__popup-menu, .function-picker__function-chooser {
  padding: 5px;
  background-color: #eee;
  border: 1px solid #eee;
  border-radius: 3px; }

.function-picker__function-chooser {
  width: 265px; }
  .function-picker__function-chooser h4 {
    font-size: 12px;
    margin: 0 0 6px; }

label.function-picker__func-label {
  display: inline-block;
  width: 130px;
  font-weight: normal;
  text-transform: uppercase;
  font-size: 11px; }

.function-picker__wildcard-button {
  float: right;
  font-size: 12px; }
.filter-pane__placeholder, .filter-pane__placeholder-over, .filter-pane__placeholder-active, .filter-pane__placeholder-disabled {
  display: block;
  width: 100%;
  padding: 0 0.5em;
  border: 1px solid rgba(77, 77, 77, 0.1);
  background-color: white;
  line-height: 20px;
  border-radius: 3px;
  text-overflow: ellipsis;
  font-weight: normal;
  color: #ccc; }

.filter-pane__placeholder-over, .filter-pane__placeholder-active {
  border: 1px dashed #4CAF50;
  background-color: #d0efb3;
  color: #212121; }

.filter-pane__placeholder-active {
  background-color: #C8E6C9; }

.filter-pane__placeholder-disabled {
  background-color: #e0e0e0;
  color: grey; }

.filter-pane__filter-shelf {
  background-color: white;
  border-radius: 3px;
  border: 1px solid #ddd;
  margin-bottom: 4px;
  max-height: 150px;
  overflow: scroll; }

.filter-pane__filter-pane {
  max-height: calc(40vh);
  overflow-y: auto;
  overflow-x: hidden; }
.one-of-filter-shelf__select-all, .one-of-filter-shelf__clear-all {
  color: #4B0082;
  cursor: pointer;
  font-size: 11px;
  margin: 4px; }

.one-of-filter-shelf__select-all:hover, .one-of-filter-shelf__clear-all:hover {
  color: #2980b9; }

.one-of-filter-shelf__keep-only {
  color: transparent;
  cursor: pointer;
  -webkit-box-flex: 1;
      -ms-flex-positive: 1;
          flex-grow: 1;
  text-align: right; }

.one-of-filter-shelf__keep-only:hover {
  color: gray; }

.one-of-filter-shelf__option-row {
  margin: 4px;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
      -ms-flex-pack: justify;
          justify-content: space-between; }

.one-of-filter-shelf__search {
  margin-right: 1px; }

.one-of-filter-shelf__below-header {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
      -ms-flex-pack: justify;
          justify-content: space-between;
  margin: 2px; }
.range-filter-shelf__range-filter-pane {
  width: 80%;
  margin-left: auto;
  margin-right: auto;
  margin: 10px auto; }
  .range-filter-shelf__range-filter-pane input {
    font-size: 11px;
    border: 0;
    outline: 0;
    background: transparent;
    padding-bottom: 1px; }
  .range-filter-shelf__range-filter-pane input:focus, .range-filter-shelf__range-filter-pane input:hover {
    border-bottom: 1px solid #999;
    padding-bottom: 0; }
  .range-filter-shelf__range-filter-pane a {
    display: inline; }

.range-filter-shelf__bound {
  font-size: 10px; }

.range-filter-shelf__date-time-picker-wrapper {
  padding: 5px;
  background-color: #eee;
  border: 1px solid #eee;
  border-radius: 3px; }

.rc-slider {
  position: relative;
  height: 14px;
  padding: 5px 0;
  width: 100%;
  border-radius: 6px;
  -ms-touch-action: none;
  touch-action: none;
  box-sizing: border-box;
  -webkit-tap-highlight-color: transparent; }

.rc-slider * {
  box-sizing: border-box;
  -webkit-tap-highlight-color: transparent; }

.rc-slider-rail {
  position: absolute;
  width: 100%;
  background-color: #e9e9e9;
  height: 4px;
  border-radius: 6px; }

.rc-slider-track {
  position: absolute;
  left: 0;
  height: 4px;
  border-radius: 6px;
  background-color: #1f77b4; }

.rc-slider-handle {
  position: absolute;
  margin-left: -7px;
  margin-top: -5px;
  width: 14px;
  height: 14px;
  cursor: pointer;
  cursor: -webkit-grab;
  cursor: grab;
  border-radius: 50%;
  border: solid 2px #1f77b4;
  background-color: #fff;
  -ms-touch-action: pan-x;
  touch-action: pan-x; }

.rc-slider-handle:hover {
  border-color: #1f9cb4; }

.rc-slider-handle:active {
  border-color: #1f9cb4;
  box-shadow: 0 0 5px #1f9cb4;
  cursor: -webkit-grabbing;
  cursor: grabbing; }

.rc-slider-mark {
  position: absolute;
  top: 18px;
  left: 0;
  width: 100%;
  font-size: 12px; }

.rc-slider-mark-text {
  position: absolute;
  display: inline-block;
  vertical-align: middle;
  text-align: center;
  cursor: pointer;
  color: #999; }

.rc-slider-mark-text-active {
  color: #666; }

.rc-slider-step {
  position: absolute;
  width: 100%;
  height: 4px;
  background: transparent; }

.rc-slider-dot {
  position: absolute;
  bottom: -2px;
  margin-left: -4px;
  width: 8px;
  height: 8px;
  border: 2px solid #e9e9e9;
  background-color: #fff;
  cursor: pointer;
  border-radius: 50%;
  vertical-align: middle; }

.rc-slider-dot:first-child {
  margin-left: -4px; }

.rc-slider-dot:last-child {
  margin-left: -4px; }

.rc-slider-dot-active {
  border-color: #96dbfa; }

.rc-slider-disabled {
  background-color: #e9e9e9; }

.rc-slider-disabled .rc-slider-track {
  background-color: #ccc; }

.rc-slider-disabled .rc-slider-handle,
.rc-slider-disabled .rc-slider-dot {
  border-color: #ccc;
  box-shadow: none;
  background-color: #fff;
  cursor: not-allowed; }

.rc-slider-disabled .rc-slider-mark-text,
.rc-slider-disabled .rc-slider-dot {
  cursor: not-allowed !important; }

.rc-slider-vertical {
  width: 14px;
  height: 100%;
  padding: 0 5px; }

.rc-slider-vertical .rc-slider-rail {
  height: 100%;
  width: 4px; }

.rc-slider-vertical .rc-slider-track {
  left: 5px;
  bottom: 0;
  width: 4px; }

.rc-slider-vertical .rc-slider-handle {
  margin-left: -5px;
  margin-bottom: -7px;
  -ms-touch-action: pan-y;
  touch-action: pan-y; }

.rc-slider-vertical .rc-slider-mark {
  top: 0;
  left: 18px;
  height: 100%; }

.rc-slider-vertical .rc-slider-step {
  height: 100%;
  width: 4px; }

.rc-slider-vertical .rc-slider-dot {
  left: 2px;
  margin-bottom: -4px; }

.rc-slider-vertical .rc-slider-dot:first-child {
  margin-bottom: -4px; }

.rc-slider-vertical .rc-slider-dot:last-child {
  margin-bottom: -4px; }

.rc-slider-tooltip-zoom-down-enter,
.rc-slider-tooltip-zoom-down-appear {
  -webkit-animation-duration: .3s;
  animation-duration: .3s;
  -webkit-animation-fill-mode: both;
  animation-fill-mode: both;
  display: block !important;
  -webkit-animation-play-state: paused;
  animation-play-state: paused; }

.rc-slider-tooltip-zoom-down-leave {
  -webkit-animation-duration: .3s;
  animation-duration: .3s;
  -webkit-animation-fill-mode: both;
  animation-fill-mode: both;
  display: block !important;
  -webkit-animation-play-state: paused;
  animation-play-state: paused; }

.rc-slider-tooltip-zoom-down-enter.rc-slider-tooltip-zoom-down-enter-active,
.rc-slider-tooltip-zoom-down-appear.rc-slider-tooltip-zoom-down-appear-active {
  -webkit-animation-name: rcSliderTooltipZoomDownIn;
  animation-name: rcSliderTooltipZoomDownIn;
  -webkit-animation-play-state: running;
  animation-play-state: running; }

.rc-slider-tooltip-zoom-down-leave.rc-slider-tooltip-zoom-down-leave-active {
  -webkit-animation-name: rcSliderTooltipZoomDownOut;
  animation-name: rcSliderTooltipZoomDownOut;
  -webkit-animation-play-state: running;
  animation-play-state: running; }

.rc-slider-tooltip-zoom-down-enter,
.rc-slider-tooltip-zoom-down-appear {
  -webkit-transform: scale(0, 0);
  transform: scale(0, 0);
  -webkit-animation-timing-function: cubic-bezier(0.23, 1, 0.32, 1);
  animation-timing-function: cubic-bezier(0.23, 1, 0.32, 1); }

.rc-slider-tooltip-zoom-down-leave {
  -webkit-animation-timing-function: cubic-bezier(0.755, 0.05, 0.855, 0.06);
  animation-timing-function: cubic-bezier(0.755, 0.05, 0.855, 0.06); }

@-webkit-keyframes range-filter-shelf__rcSliderTooltipZoomDownIn {
  0% {
    opacity: 0;
    -webkit-transform-origin: 50% 100%;
    transform-origin: 50% 100%;
    -webkit-transform: scale(0, 0);
    transform: scale(0, 0); }
  100% {
    -webkit-transform-origin: 50% 100%;
    transform-origin: 50% 100%;
    -webkit-transform: scale(1, 1);
    transform: scale(1, 1); } }

@keyframes range-filter-shelf__rcSliderTooltipZoomDownIn {
  0% {
    opacity: 0;
    -webkit-transform-origin: 50% 100%;
    transform-origin: 50% 100%;
    -webkit-transform: scale(0, 0);
    transform: scale(0, 0); }
  100% {
    -webkit-transform-origin: 50% 100%;
    transform-origin: 50% 100%;
    -webkit-transform: scale(1, 1);
    transform: scale(1, 1); } }

@-webkit-keyframes range-filter-shelf__rcSliderTooltipZoomDownOut {
  0% {
    -webkit-transform-origin: 50% 100%;
    transform-origin: 50% 100%;
    -webkit-transform: scale(1, 1);
    transform: scale(1, 1); }
  100% {
    opacity: 0;
    -webkit-transform-origin: 50% 100%;
    transform-origin: 50% 100%;
    -webkit-transform: scale(0, 0);
    transform: scale(0, 0); } }

@keyframes range-filter-shelf__rcSliderTooltipZoomDownOut {
  0% {
    -webkit-transform-origin: 50% 100%;
    transform-origin: 50% 100%;
    -webkit-transform: scale(1, 1);
    transform: scale(1, 1); }
  100% {
    opacity: 0;
    -webkit-transform-origin: 50% 100%;
    transform-origin: 50% 100%;
    -webkit-transform: scale(0, 0);
    transform: scale(0, 0); } }

.rc-slider-tooltip {
  position: absolute;
  left: -9999px;
  top: -9999px;
  visibility: visible;
  box-sizing: border-box;
  -webkit-tap-highlight-color: transparent; }

.rc-slider-tooltip * {
  box-sizing: border-box;
  -webkit-tap-highlight-color: transparent; }

.rc-slider-tooltip-hidden {
  display: none; }

.rc-slider-tooltip-placement-top {
  padding: 4px 0 8px 0; }

.rc-slider-tooltip-inner {
  padding: 6px 2px;
  min-width: 24px;
  height: 24px;
  font-size: 12px;
  line-height: 1;
  color: #fff;
  text-align: center;
  text-decoration: none;
  background-color: #6c6c6c;
  border-radius: 6px;
  box-shadow: 0 0 4px #d9d9d9; }

.rc-slider-tooltip-arrow {
  position: absolute;
  width: 0;
  height: 0;
  border-color: transparent;
  border-style: solid; }

.rc-slider-tooltip-placement-top .rc-slider-tooltip-arrow {
  bottom: 4px;
  left: 50%;
  margin-left: -4px;
  border-width: 4px 4px 0;
  border-top-color: #6c6c6c; }
.encoding-pane__encoding-pane {
  background-color: #E2E9F3; }

.encoding-pane__shelf-group {
  margin-bottom: 12px; }
.encoding-shelf__placeholder, .encoding-shelf__placeholder-over, .encoding-shelf__placeholder-active, .encoding-shelf__placeholder-disabled {
  display: block;
  width: 100%;
  padding: 0 0.5em;
  border: 1px solid rgba(77, 77, 77, 0.1);
  background-color: white;
  line-height: 20px;
  border-radius: 3px;
  text-overflow: ellipsis;
  font-weight: normal;
  color: #ccc; }

.encoding-shelf__placeholder-over, .encoding-shelf__placeholder-active {
  border: 1px dashed #4CAF50;
  background-color: #d0efb3;
  color: #212121; }

.encoding-shelf__placeholder-active {
  background-color: #C8E6C9; }

.encoding-shelf__placeholder-disabled {
  background-color: #e0e0e0;
  color: grey; }

.encoding-shelf__encoding-shelf, .encoding-shelf__wildcard-shelf {
  background-color: rgba(55, 65, 92, 0.2);
  border: 1px solid #ddd;
  border-radius: 3px;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  font-size: 11px;
  margin-bottom: 4px;
  width: 100%;
  height: 22px; }

.encoding-shelf__field-wrapper {
  -webkit-box-flex: 1;
      -ms-flex-positive: 1;
          flex-grow: 1;
  box-sizing: border-box;
  border: 1px solid transparent;
  border-radius: 3px;
  width: 168px;
  height: 22px; }

.encoding-shelf__wildcard-shelf {
  background-color: rgba(15, 123, 133, 0.4); }

.encoding-shelf__shelf-label {
  -webkit-user-select: none;
     -moz-user-select: none;
      -ms-user-select: none;
          user-select: none;
  display: block;
  width: 52px;
  margin: 0 0.2rem;
  line-height: 22px;
  -ms-flex-negative: 0;
      flex-shrink: 0; }
  .encoding-shelf__shelf-label .fa {
    margin-top: 4px;
    opacity: 0.5; }

.encoding-shelf__overlay-screen {
  z-index: 1;
  position: fixed;
  top: 0;
  bottom: 0;
  left: 0;
  right: 0; }
.field-customizer__customizer-container {
  padding: 5px;
  background-color: #eee;
  border: 1px solid #eee;
  border-radius: 3px; }
.property-editor__property-editor .form-group {
  font-size: 11px; }
  .property-editor__property-editor .form-group label {
    font-size: 12px;
    font-weight: bold;
    margin: 5px; }
  .property-editor__property-editor .form-group div {
    display: inline-block; }
  .property-editor__property-editor .form-group select:focus {
    outline: none; }
.mark-picker__mark-picker {
  background: #f8f8f8;
  color: #333;
  border: #888888 1px solid; }

.mark-picker__mark-picker-any {
  background: #e3f9fd;
  color: #5798a5;
  border: #9bc4cc 1px solid; }
.footer__footer {
  background-color: transparent;
  position: fixed;
  left: 10px;
  bottom: 10px; }
  .footer__footer a {
    color: #fff;
    background-color: transparent;
    text-decoration: none; }
  .footer__footer a:hover {
    color: #ddd;
    cursor: pointer; }
.bookmarkbutton__plot-group, .bookmarkbutton__plot-list-item-group {
  background-color: white;
  overflow: hidden;
  text-align: center;
  padding: 8px;
  max-height: 600px;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
      -ms-flex-direction: column;
          flex-direction: column; }

.bookmarkbutton__plot-list-item-group {
  margin: 4px 4px 0 0;
  -webkit-box-flex: 1;
      -ms-flex-positive: 1;
          flex-grow: 1;
  max-height: 290px; }

.bookmarkbutton__plot {
  overflow: hidden;
  padding-right: 11px; }

.bookmarkbutton__plot-scroll {
  overflow: auto;
  padding-right: 0px; }

.bookmarkbutton__plot-info {
  text-align: left;
  margin-bottom: 6px; }

.bookmarkbutton__plot-field-info {
  display: inline-block;
  margin-right: 4px; }

.bookmarkbutton__command-toolbox {
  float: right; }

.bookmarkbutton__command, .bookmarkbutton__sort-x-command, .bookmarkbutton__specify-command, .bookmarkbutton__bookmark-command-selected {
  cursor: pointer;
  margin-left: 10px;
  color: #aaa; }

.bookmarkbutton__sort-x-command {
  -webkit-transform: rotateZ(270deg);
          transform: rotateZ(270deg); }

.bookmarkbutton__command:hover, .bookmarkbutton__sort-x-command:hover, .bookmarkbutton__specify-command:hover, .bookmarkbutton__bookmark-command-selected:hover {
  color: #72c1d5; }

.bookmarkbutton__specify-command {
  -webkit-transform: scaleX(-1);
          transform: scaleX(-1); }

.bookmarkbutton__copied {
  font-size: 12px; }

.bookmarkbutton__note {
  min-height: 60px;
  resize: none;
  border-color: #d3d3d3;
  width: 100%; }

.bookmarkbutton__bookmark-alert {
  color: #fff;
  background-color: #38425d;
  padding: 8px;
  font-size: 14px;
  line-height: 18px;
  min-width: 150px;
  border-radius: 3px; }

.bookmarkbutton__bookmark-command-selected {
  color: #0c96d0; }
.plot__plot-group, .plot__plot-list-item-group {
  background-color: white;
  overflow: hidden;
  text-align: center;
  padding: 8px;
  max-height: 600px;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
      -ms-flex-direction: column;
          flex-direction: column; }

.plot__plot-list-item-group {
  margin: 4px 4px 0 0;
  -webkit-box-flex: 1;
      -ms-flex-positive: 1;
          flex-grow: 1;
  max-height: 290px; }

.plot__plot {
  overflow: hidden;
  padding-right: 11px; }

.plot__plot-scroll {
  overflow: auto;
  padding-right: 0px; }

.plot__plot-info {
  text-align: left;
  margin-bottom: 6px; }

.plot__plot-field-info {
  display: inline-block;
  margin-right: 4px; }

.plot__command-toolbox {
  float: right; }

.plot__command, .plot__sort-x-command, .plot__specify-command {
  cursor: pointer;
  margin-left: 10px;
  color: #aaa; }

.plot__sort-x-command {
  -webkit-transform: rotateZ(270deg);
          transform: rotateZ(270deg); }

.plot__command:hover, .plot__sort-x-command:hover, .plot__specify-command:hover {
  color: #72c1d5; }

.plot__specify-command {
  -webkit-transform: scaleX(-1);
          transform: scaleX(-1); }

.plot__copied {
  font-size: 12px; }

.plot__note {
  min-height: 60px;
  resize: none;
  border-color: #d3d3d3;
  width: 100%; }
.bookmark__modal {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  margin: 50px auto;
  width: calc( 100% - 100px);
  padding: 6px;
  background-color: #E2E9F3;
  border: 1px solid #aaa;
  border-radius: 3px;
  box-sizing: border-box;
  display: flex;
  box-orient: vertical;
  box-direction: normal;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
      -ms-flex-direction: column;
          flex-direction: column;
  box-align: stretch;
  -webkit-box-align: stretch;
      -ms-flex-align: stretch;
          align-items: stretch;
  max-width: 800px;
  max-height: calc(100% - 100px);
  overflow: scroll; }

.bookmark__vis-list-empty {
  height: 60px;
  line-height: 60px;
  vertical-align: middle;
  text-align: center;
  font-size: 1.2em; }

a:hover {
  cursor: pointer; }

.bookmark__bookmark-list-util {
  margin-right: 10px; }
.controls__controls {
  display: inline-block;
  margin-top: auto;
  margin-bottom: auto; }

.controls__controls div {
  display: inline-block; }

.controls__controls button {
  font-size: 14px;
  margin-left: 10px;
  margin-right: 50px;
  cursor: pointer;
  border: none;
  background-color: transparent; }

.controls__controls button:focus {
  outline: none; }

.controls__controls button:disabled {
  color: #ccc;
  cursor: not-allowed; }
.header__voyager-logo {
  width: 176px;
  height: 33px;
  margin-right: 57px; }

.header__idl-logo {
  position: absolute;
  right: 8px;
  display: inline-block; }

.header__idl-logo img {
  width: 40px; }

.header__header {
  background-color: white;
  height: 33px;
  padding: 8px;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: start;
      -ms-flex-pack: start;
          justify-content: flex-start;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center; }
.load-data-pane__load-data-pane {
  text-align: center;
  margin-top: 100px;
  font-size: 24px; }
.log-pane__log-pane, .log-pane__error-pane, .log-pane__warning-pane {
  margin-left: -100px;
  z-index: 10;
  max-width: 500px;
  position: absolute;
  top: 15px;
  padding: 15px;
  border: 1px solid transparent;
  border-radius: 4px;
  left: 50%; }
  .log-pane__log-pane ul, .log-pane__error-pane ul, .log-pane__warning-pane ul {
    margin: 0;
    padding: 0; }
  .log-pane__log-pane li, .log-pane__error-pane li, .log-pane__warning-pane li {
    list-style-type: none;
    margin: 5px;
    padding-left: 10px; }

.log-pane__error-pane {
  background-color: #f2dede;
  color: #a94442; }

.log-pane__warning-pane {
  background-color: #fff9e5;
  color: #FFCC00; }

.log-pane__close {
  position: absolute;
  top: 5px;
  right: 5px; }
.plot-list__plot-list {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: stretch;
      -ms-flex-align: stretch;
          align-items: stretch;
  -ms-flex-line-pack: start;
      align-content: flex-start;
  -ms-flex-wrap: wrap;
      flex-wrap: wrap; }

.plot-list__plot-list-loading {
  min-height: 290px;
  margin: auto;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex; }

.plot-list__load-more {
  display: block;
  background: #e2e9f3;
  height: 60px;
  line-height: 60px;
  vertical-align: middle;
  text-align: center;
  font-size: 1.2em;
  margin-bottom: 20px; }
.related-views__related-views-subpane {
  margin-top: 20px; }
  .related-views__related-views-subpane h3 {
    display: inline-block; }

.related-views__command {
  cursor: pointer;
  margin-left: 10px;
  color: #aaa; }
.view-pane__view-pane, .view-pane__view-pane-gallery {
  overflow: scroll;
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  right: 0; }

.view-pane__view-pane-specific, .view-pane__view-pane-related-views {
  background: rgba(255, 255, 255, 0.6); }

.view-pane__view-pane-related-views {
  margin-top: 20px; }

.view-pane__view-pane-gallery {
  background: #C6E5E7;
  height: 100%; }

.view-pane__gallery-command {
  margin-left: 10px; }

/*# sourceMappingURL=style.css.map*/